@@ -23,6 +23,14 @@ class Mutator:
         """
         return ''
 
+    @staticmethod
+    def mutation_fixed_value(**kwargs) -> str:
+        """
+        Метод для вставки значения из параметров
+        :return: строка со значением
+        """
+        return str(kwargs.get('value', ''))
+
     def mutation_first_name(self, **_) -> str:
         """
         Метод для формирования фамилии
@@ -53,6 +61,22 @@ class Mutator:
         """Метод для формирования адреса"""
         return self._faker.address()
 
+    def mutation_past_date(self, **kwargs) -> str:
+        """
+        Метод для формирования даты в прошедшем времени.
+        start_date - самая ранняя допустимая дата в strtotime() формате
+        """
+        start_date = kwargs.get('start_date', '-30d')
+        return self._faker.past_date(start_date=start_date).strftime('%Y-%m-%d')
+
+    def mutation_future_date(self, **kwargs) -> str:
+        """
+        Метод для формирования даты в будущем времени
+        end_date - самая поздняя допустимая дата в strtotime() формате
+        """
+        end_date = kwargs.get('end_date', '+30d')
+        return self._faker.future_date(end_date=end_date).strftime('%Y-%m-%d')
+
     def mutation_uri(self, **kwargs) -> str:
         """Метод для формирования uri"""
         max_length = kwargs.get('max_length', 2048)
